==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetSolutionsControllerSolutionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetSolutionsControllerSolutionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property migrateProjectName Name of the Azure Migrate project.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property solutionName Unique name of a migration solution within a migrate project.
 */
public data class GetSolutionsControllerSolutionPlainArgs(
    public val migrateProjectName: String,
    public val resourceGroupName: String,
    public val solutionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetSolutionsControllerSolutionPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.migrate.inputs.GetSolutionsControllerSolutionPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetSolutionsControllerSolutionPlainArgs.builder()
            .migrateProjectName(migrateProjectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .solutionName(solutionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSolutionsControllerSolutionPlainArgs].
 */
@PulumiTagMarker
public class GetSolutionsControllerSolutionPlainArgsBuilder internal constructor() {
    private var migrateProjectName: String? = null

    private var resourceGroupName: String? = null

    private var solutionName: String? = null

    /**
     * @param value Name of the Azure Migrate project.
     */
    @JvmName("pafdcbndtarviyun")
    public suspend fun migrateProjectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.migrateProjectName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("dgjppcjobcnywsiy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Unique name of a migration solution within a migrate project.
     */
    @JvmName("kohpoyunbehjryth")
    public suspend fun solutionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.solutionName = mapped
    }

    internal fun build(): GetSolutionsControllerSolutionPlainArgs =
        GetSolutionsControllerSolutionPlainArgs(
            migrateProjectName = migrateProjectName ?: throw PulumiNullFieldException("migrateProjectName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            solutionName = solutionName ?: throw PulumiNullFieldException("solutionName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GetSolutionsControllerSolutionPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GetSolutionsControllerSolutionPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property migrateProjectName Name of the Azure Migrate project.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property solutionName Unique name of a migration solution within a migrate project.
 */
public data class GetSolutionsControllerSolutionPlainArgs(
    public val migrateProjectName: String,
    public val resourceGroupName: String,
    public val solutionName: String,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GetSolutionsControllerSolutionPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.migrate.inputs.GetSolutionsControllerSolutionPlainArgs =
        com.pulumi.azurenative.migrate.inputs.GetSolutionsControllerSolutionPlainArgs.builder()
            .migrateProjectName(migrateProjectName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .solutionName(solutionName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSolutionsControllerSolutionPlainArgs].
 */
@PulumiTagMarker
public class GetSolutionsControllerSolutionPlainArgsBuilder internal constructor() {
    private var migrateProjectName: String? = null

    private var resourceGroupName: String? = null

    private var solutionName: String? = null

    /**
     * @param value Name of the Azure Migrate project.
     */
    @JvmName("cqkxlrehngakhiap")
    public suspend fun migrateProjectName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.migrateProjectName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("gcsjiugfglpnoxpn")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Unique name of a migration solution within a migrate project.
     */
    @JvmName("mxkwybnejjnfmpul")
    public suspend fun solutionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.solutionName = mapped
    }

    internal fun build(): GetSolutionsControllerSolutionPlainArgs =
        GetSolutionsControllerSolutionPlainArgs(
            migrateProjectName = migrateProjectName ?: throw PulumiNullFieldException("migrateProjectName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            solutionName = solutionName ?: throw PulumiNullFieldException("solutionName"),
        )
}
